# oneNeuron Python package

## How to use this package
'''python
from oneNeuron.perceptron import Perceptron
model= Perceptron(eta=0.3, epochs=10)
'''

## References - 

* [Official python docs for Pypi](https://packaging.python.org/en/latest/tutorials/packaging-projects/)
* [Github Action file](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)
* [Package link](https://pypi.org/project/oneNeuron-pkg-Vikaslakkacs/)